@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Overlay;
-$Footprintless::Overlay::VERSION = '1.18';
+$Footprintless::Overlay::VERSION = '1.19';
 # ABSTRACT: An overlay manager
 # PODNAME: Footprintless::Overlay
 
@@ -11,6 +11,7 @@ use parent qw(Footprintless::MixableBase);
 use Carp;
 use Footprintless::Mixins qw (
     _clean
+    _command_options
     _entity
     _extract_resource
     _local_template
@@ -154,6 +155,18 @@ sub _resolve_footprintless {
     my $spec = do($template) || return;
     croak("invalid $template") unless ( ref($spec) eq 'HASH' );
 
+    if ( $spec->{clean} ) {
+        my @to_be_cleaned =
+            map { File::Spec->catdir( $destination, $_ ) . ( /\/$/ ? '/' : '' ); }
+            ref( $spec->{clean} ) ? @{ $spec->{clean} } : ( $spec->{clean} );
+
+        Footprintless::Util::clean(
+            \@to_be_cleaned,
+            command_runner  => $self->{factory}->command_runner(),
+            command_options => $self->_command_options()
+        );
+    }
+
     if ( $spec->{resources} ) {
         my $resource_manager = $self->{factory}->resource_manager();
         foreach my $resource ( keys( %{ $spec->{resources} } ) ) {
@@ -201,7 +214,7 @@ Footprintless::Overlay - An overlay manager
 
 =head1 VERSION
 
-version 1.18
+version 1.19
 
 =head1 SYNOPSIS
 
@@ -221,6 +234,26 @@ Overlays are a combination of a directory of static files and a directory
 of templated files that will be merged to an output directory.  This
 is implemented in L<Template::Overlay>.  
 
+Additionally, any folder under the C<template_dir> can contain a 
+C<.footprintless> file containing a C<clean> and/or C<resources> entities:
+
+    return {
+        clean => [
+            'foo.jar',
+            'bar.jar',
+            'ext/'
+        ],
+        resources => {
+            foo => 'com.pastdev:foo:1.0.0',
+            bar => 'com.pastdev:bar:1.0.0'
+        }
+    };
+
+The C<clean> entity is an arrayref containing a list of paths to clean out.
+These paths will be added to the path of the directory containing the
+C<.footprintless> file.  The C<resources> entity is a list of resources to
+download into the same directory as the C<.footprintless> file.
+
 =head1 ENTITIES
 
 A simple overlay: 
